@@ -15,7 +15,7 @@
 
 package Whisper;
 {
-  $Whisper::VERSION = '1.026';
+  $Whisper::VERSION = '1.031';
 }
 
 use strict;
@@ -104,7 +104,9 @@ sub __read_archiveinfo {
 }
 
 sub wsp_info {
-	my $dbfile = shift;
+	my %param = @_;
+
+	my $dbfile = $param{file};
 
 	die("You need to specify a wsp file\n") unless $dbfile;
 
@@ -119,7 +121,13 @@ sub wsp_info {
 }
 
 sub wsp_fetch {
-	my ($dbfile, $from, $until, $do_tuples, $date_format) = @_;
+	my %param = @_;
+
+	my $dbfile = $param{file};
+	my $from = $param{from};
+	my $until = $param{until};
+	my $format = $param{format};
+	my $date_format = $param{date_format};
 
 	die("You need to specify a wsp file\n") unless $dbfile;
 	
@@ -225,7 +233,7 @@ sub wsp_fetch {
 	}
 
 	# Generate datetime,data tuples
-	if( $do_tuples ) {
+	if( $format eq 'tuples' ) {
 
 		my $current = $from_interval;
 		while( my ($i, $val) = each @$values ) {
